#ifndef __PokktNativeManager__
#define __PokktNativeManager__

#include <stdio.h>
#include <stdlib.h>
#include <string>
#include <map>
#include "PokktExtension.h"
#include "PokktMarmaladeConfig.h"
#include "PokktDelegate.h"
#include "IwDebug.h"

class PokktNativeManager;

typedef void (PokktDelegate::*EVT_SELECTOR)(std::string);
#define pokkt_event_selector(_SELECTOR) (EVT_SELECTOR)(&_SELECTOR)

#define POKKTLOG(format, ...)      if (PokktNativeManager::getDebug()) IwDebugTraceLinePrintf(format, ##__VA_ARGS__)

class PokktNativeManager
{
    friend class PokktExtension;
    
public:
    
    // events
    static const std::string VideoClosedEvent;
    static const std::string VideoDisplayedEvent;
    static const std::string VideoSkippedEvent;
    static const std::string VideoCompletedEvent;
    static const std::string VideoGratifiedEvent;
    static const std::string ShowIntent;
    static const std::string DownloadCompletedEvent;
    static const std::string DownloadFailedEvent;
    static const std::string CoinResponseEvent;
    static const std::string CoinResponseWithTransIdEvent;
    static const std::string CoinResponseFailedEvent;
    static const std::string CampaignAvailabilityEvent;
    static const std::string OfferwallClosedEvent;
        
    // common methods
    static void initPokkt(PokktMarmaladeConfig *pokktMarmaladeConfig);
    static void setDebug(bool value);
    static bool getDebug();
    static void showLog(std::string message);
    static void showToast(std::string message);
    
    // session methods
    static void startSession(PokktMarmaladeConfig *pokktMarmaladeConfig);
    static void endSession();
    
    // offerwall methods
    static void getCoins(PokktMarmaladeConfig *pokktMarmaladeConfig);
    static void getPendingCoins();
    static void checkOfferWallCampaign();
    
    // video methods
    static void getVideo(PokktMarmaladeConfig *pokktMarmaladeConfig);
    static void getVideoNonIncent(PokktMarmaladeConfig *pokktMarmaladeConfig);
    static void cacheVideoCampaign();
    static bool isVideoAvailable();
    static double getVideoVc();
    
    static void sendAppInfo();
    static void exportLogs();
    
    static void terminatePokktNativeManager();
    
    static std::string getPokktSDKVersion();
        
//protected:
    
    // handles messages coming from native pokkt runtime
    static void handleNativeMessage(const char* operation, const char* param);
    
    // sets a listener for an event (only one listener per event
    static void setListener(std::string eventName, EVT_SELECTOR listener, PokktDelegate *target);
    static void removeListener(std::string eventName);
    static void removeAllListeners();
    
private:
    
    typedef struct __listenerTargetPair
    {
        EVT_SELECTOR listener;
        PokktDelegate *target;
    }ListenerTargetPair;
    
    static bool _isDebugEnabled;
    
    static _STL::map<std::string , ListenerTargetPair*> _eventMap;
    
    static void setParams(PokktMarmaladeConfig *pokktMarmaladeConfig);
};

#endif /* defined(__PokktNativeManager__) */
