//package com.pokkt.cocos2dx;

import android.app.Activity;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.widget.Toast;

import com.app.pokktsdk.PokktConfig;
import com.app.pokktsdk.PokktManager;
import com.app.pokktsdk.enums.PokktIntegrationType;
import com.app.pokktsdk.util.Logger;
import com.app.pokktsdk.enums.AnalyticsType;

import com.ideaworks3d.marmalade.LoaderAPI;
import com.ideaworks3d.marmalade.LoaderActivity;
import com.app.pokktsdk.util.PokktUtils;

public class PokktManagerHandler {

	private static final PokktConfig pokktConfig = new PokktConfig();
	
    /**
     * events: string values must be in sync with cpp events string values
     */
    protected static final String VideoClosedEvent = "videoClosed";
    protected static final String VideoDisplayedEvent = "videoDisplayed";
    protected static final String VideoSkippedEvent = "videoSkipped";
    protected static final String VideoCompletedEvent = "videoCompleted";
    protected static final String VideoGratifiedEvent = "videoGratified";
    protected static final String DownloadCompletedEvent = "downloadCompleted";
    protected static final String DownloadFailedEvent = "downloadFailed";
    protected static final String CoinResponseEvent = "coinResponse";
    protected static final String CoinResponseWithTransIdEvent = "coinResponseWithTrId";
    protected static final String CoinResponseFailedEvent = "coinResponseFailed";
    protected static final String CampaignAvailabilityEvent = "campaignAvailability";
    protected static final String OfferwallClosedEvent = "offerwallClosedEvent";

    private PokktManagerHandler() {
        try {
        } catch (Exception e) {
            Logger.printStackTrace("Exception occurred locating getActivity(): ",e);
        }
    }

    protected static Activity getActivity() {
        return LoaderActivity.m_Activity;
    }

// PRAGMA -- Common Methods
    
    public static void setParams(String params) {
        Logger.d("set Params method Called");
        // decode params
    	try {
    		if (params != null && !"".equalsIgnoreCase(params.trim())) {
		        String values[] = params.split(",");
                pokktConfig.setSecurityKey(values[0]);
                pokktConfig.setApplicationId(values[1]);
                pokktConfig.setIntegrationType(PokktIntegrationType.tryParse(Integer.parseInt(values[2])));
                pokktConfig.setAutoCacheVideo(Boolean.parseBoolean(values[3]));
	    	}
            PokktManager.initPokkt(getActivity(), pokktConfig);
    	} catch (Exception e) {
    		Logger.printStackTrace("Exception occured in setParams ",e);
    	}
    }

    public static void setDebug(boolean debug) {
        Logger.d("set DEBUG method Called");
        PokktManager.setDebug(debug);
    }

    public static void showLog( String msg) {
        Logger.d("showLog method Called");
        Logger.e(msg);
    }

    // Method to show toast from unity
    public static void showToast(final String message) {
        Logger.d("show Toast method Called");
        getActivity().runOnUiThread(new Runnable() {
            final Message msg = new Message();

            public void run() {

                if (Looper.myLooper() == null) {
                    Looper.prepare();
                }

                Handler handler = new Handler() {
                    public void handleMessage(Message msg) {
                        if (msg.arg1 == 1) {
                            Toast.makeText(getActivity(), message, Toast.LENGTH_LONG).show();
                        }
                    }
                };

                msg.arg1 = 1;
                handler.sendMessage(msg);

                Looper.loop();
            }
        });
    }

    public static void setThirdPartyUserId(final String thirdPartyUserId) {
        Logger.d("set thirdPartyUserId method Called");
        pokktConfig.setThirdPartyUserId(thirdPartyUserId);
    }

    // PRAGMA -- Session Methods

    public static void startSession(){
        Logger.d("startSession method Called");
        PokktManager.startSession(getActivity(),pokktConfig);
    }

    public static void endSession(){
        Logger.d("endSession method Called");
        PokktManager.endSession();
    }

    // PRAGMA -- OfferWall Methods

    public static void setCloseOnSuccessFlag(boolean closeOnSuccessFlag){
        Logger.d("setCloseOnSuccessFlag method Called");
        pokktConfig.setCloseOnSuccessFlag(closeOnSuccessFlag);
    }
    
    public static void getCoins(final String limit) {
        Logger.d("get coins method Called");
        getActivity().runOnUiThread(new Runnable() {
            final Message msg = new Message();

            public void run() {
                if (Looper.myLooper() == null) {
                    Looper.prepare();
                }

                Handler handler = new Handler() {
                    public void handleMessage(Message msg) {
                        if (msg.arg1 == 1) {
                        	pokktConfig.setOfferWallAssetValue(limit);
                        	
                        	PokktManager.getCoins(getActivity(), pokktConfig);
                        }
                    }
                };

                msg.arg1 = 1;
                handler.sendMessage(msg);

                Looper.loop();
            }
        });
    }

    public static void getPendingCoins() {
        Logger.d("get pending coins method Called");
        getActivity().runOnUiThread(new Runnable() {
            final Message msg = new Message();

            public void run() {
                if (Looper.myLooper() == null) {
                    Looper.prepare();
                }

                Handler handler = new Handler() {
                    public void handleMessage(Message msg) {
                        if (msg.arg1 == 1) {
                            PokktManager.getPendingCoins(getActivity(), pokktConfig);
                        }
                    }
                };

                msg.arg1 = 1;
                handler.sendMessage(msg);

                Looper.loop();
            }
        });
    }

    public static void checkOfferWallCampaign() {
        Logger.d("check offerWall campaign method Called");
        getActivity().runOnUiThread(new Runnable() {
            final Message msg = new Message();

            public void run() {

                if (Looper.myLooper() == null) {
                    Looper.prepare();
                }

                Handler handler = new Handler() {
                    public void handleMessage(Message msg) {
                        if (msg.arg1 == 1) {
                            PokktManager.checkCampaignAvailable(getActivity(), pokktConfig);
                        }
                    }
                };

                msg.arg1 = 1;
                handler.sendMessage(msg);

                Looper.loop();
            }
        });
    }

    // PRAGMA -- Video Methods

    public static void getVideo(final String screenName) { // needed
        Logger.d("get video method Called");
        getActivity().runOnUiThread(new Runnable() {
            final Message msg = new Message();

            public void run() {

                if (Looper.myLooper() == null) {
                    Looper.prepare();
                }

                Handler handler = new Handler() {
                    public void handleMessage(Message msg) {
                        if (msg.arg1 == 1) {
                            if (PokktManager.isVideoAvailable()) {
                            	pokktConfig.setScreenName(screenName);
                            	pokktConfig.setIncentivised(true);
                            	PokktManager.playVideoCampaign(getActivity(), pokktConfig);
                            } else {
                                if (Logger.getShouldLog()) {
                                    Toast.makeText(getActivity(), "No Videos Available Right Now!!", Toast.LENGTH_LONG).show();
                                }
                            }
                        }
                    }
                };

                msg.arg1 = 1;
                handler.sendMessage(msg);

                Looper.loop();
            }
        });
    }

    public static void getVideoNonIncent(final String screenName) {
        Logger.d("get video non incent method Called");
        getActivity().runOnUiThread(new Runnable() {
            final Message msg = new Message();

            public void run() {

                if (Looper.myLooper() == null) {
                    Looper.prepare();
                }

                Handler handler = new Handler() {
                    public void handleMessage(Message msg) {
                        if (msg.arg1 == 1) {
                        	
                            if (PokktManager.isVideoAvailable()) {
                            	pokktConfig.setScreenName(screenName);
                            	pokktConfig.setIncentivised(false);
                            	PokktManager.playVideoCampaign(getActivity(), pokktConfig);
                            } else {
                                if (Logger.getShouldLog()) {
                                    Toast.makeText(getActivity(), "No Videos Available Right Now!!", Toast.LENGTH_LONG).show();
                                }
                            }
                        }
                    }
                };

                msg.arg1 = 1;
                handler.sendMessage(msg);

                Looper.loop();
            }
        });
    }
    
    public static void cacheVideoCampaign() {
        Logger.d("cache video campaign method Called");
    	getActivity().runOnUiThread(new Runnable() {
            final Message msg = new Message();

            public void run() {

                if (Looper.myLooper() == null) {
                    Looper.prepare();
                }

                Handler handler = new Handler() {
                    public void handleMessage(Message msg) {
                        if (msg.arg1 == 1) {
                        	PokktManager.cacheVideoCampaign(getActivity(), pokktConfig);
                        }
                    }
                };

                msg.arg1 = 1;
                handler.sendMessage(msg);

                Looper.loop();
            }
        });
    	
    }

    public static void setSkipEnabled(final boolean shouldSkip) {
        Logger.d("Set Skip Video method Called");
        pokktConfig.setSkipEnabled(shouldSkip);
    }

    public static void setDefaultSkipTime(final int defaultSkipTime) {
        Logger.d("Set Skip Video method Called");
        pokktConfig.setDefaultSkipTime(defaultSkipTime);
    }

    public static void setCustomSkipMessage(String customSkipMessage){
        Logger.d("setCustomSkipMessage method Called");
        pokktConfig.setCustomSkipMessage(customSkipMessage);
    }

    public static void setBackButtonDisabled(boolean backButtonDisabled){
        Logger.d("setBackButtonDisabled method Called");
        pokktConfig.setBackButtonDisabled(backButtonDisabled);
    }

    public static boolean isVideoAvailablePokkt() {
        Logger.d("isVideoAvailable method Called");
        return PokktManager.isVideoAvailable();
    }

    public static float getVideoVc() {
        Logger.d("Get VideoVC method Called");
        return PokktManager.getVideoVc(getActivity());
    }


    // PARGMA -- Optional Methods

    public static void setName(final String name) {
        pokktConfig.setName(name);
    }

    public static void setAge(final String age) {
        pokktConfig.setAge(age);
    }

    public static void setSex(final String sex) {
        pokktConfig.setSex(sex);
    }
    public static void setMobileNo(final String mobileNo) {
        pokktConfig.setMobileNo(mobileNo);
    }

    public static void setEmailAddress(final String emailAddress) {
        pokktConfig.setEmailAddress(emailAddress);
    }

    public static void setLocation(final String location) {
        pokktConfig.setLocation(location);
    }

    public static void setBirthday(final String birthday) {
        pokktConfig.setBirthday(birthday);
    }

    public static void setMaritalStatus(final String maritalStatus) {
        pokktConfig.setMaritalStatus(maritalStatus);
    }

    public static void setFacebookId(final String facebookId) {
        pokktConfig.setFacebookId(facebookId);
    }

    public static void setTwitterHandle(final String twitter_handle) {
        pokktConfig.setTwitterHandle(twitter_handle);
    }

    public static void setEducation(final String education_information) {
        pokktConfig.setEducation(education_information);
    }

    public static void setNationality(final String nationality) {
        pokktConfig.setNationality(nationality);
    }

    public static void setEmployment(final String employment) {
        pokktConfig.setEmployment(employment);
    }

    public static void setMaturityRating(String maturityRating){
        pokktConfig.setMaturityRating(maturityRating);
    }
    
    //
    public static void setGoogleAnalyticsID(String googleAnalyticsID){
        pokktConfig.setGoogleAnalyticsID(googleAnalyticsID);
    }
    
    public static void setMixPanelProjectToken(String mixPanelProjectToken){
        pokktConfig.setMixPanelProjectToken(mixPanelProjectToken);
    }
    
    public static void setFlurryApplicationKey(String flurryApplicationKey){
        pokktConfig.setFlurryApplicationKey(flurryApplicationKey);
    }
    
    public static void setSelectedAnalyticsType(String mSelectedAnalyticsType){
    	AnalyticsType analyticsType = AnalyticsType.valueOf(mSelectedAnalyticsType);
        pokktConfig.setSelectedAnalyticsType(analyticsType);
    }

    public static void sendAppInfo() {
    	PokktManager.sendAppInfo(getActivity(), pokktConfig);
    }
    
    public static void exportLog() {
    	getActivity().runOnUiThread(new Runnable() {
    		final Message msg = new Message();	
			@Override
			public void run() {
				if (Looper.myLooper() == null) {
                    Looper.prepare();
                }
                Handler _handler = new Handler() {
                    public void handleMessage(Message msg) {
                        if (msg.arg1 == 1) {
                        	PokktManager.exportLog(getActivity());
                        }
                    }
                };
                msg.arg1 = 1;
                _handler.sendMessage(msg);
                Looper.loop();
			}
		});
    }

    public static String getSDKVersion() {
        return PokktUtils.getSdkVersion();
    }
    
    //
    public static void notifyOfferwallCampaignEvent(boolean available) {
    	PokktNativeExtension.NotifyCPP(CampaignAvailabilityEvent, (available ? "true" : "false"));
    }
    
    public static void notifyOfferwallClosedEvent() {
    	PokktNativeExtension.NotifyCPP(OfferwallClosedEvent, "");
    }
}
