//
//  VideoScreen.cpp
//  PokktSample
//
//  Created by Pankaj Kumar on 22/04/15.
//
//

#include "VideoScreen.h"
#include "IwGx.h"
#include "input.h"
#include "resources.h"
#include "UIComponents.h"
#include "PokktNativeManager.h"
#include <sstream>
#include "VideoNextScreen.h"
#include "Storage.h"
#include "AnalyticsType.h"

PokktMarmaladeConfig *VideoScreen::pokktConfig = new PokktMarmaladeConfig();

VideoScreen::VideoScreen()
{
    POKKTLOG("[POKKT-CPP][VideoScreen]video download listener registered");
    
    // listen for pokkt events
    PokktNativeManager::setListener(PokktNativeManager::VideoClosedEvent, pokkt_event_selector(VideoScreen::handleVideoClosed), this);
    PokktNativeManager::setListener(PokktNativeManager::VideoDisplayedEvent, pokkt_event_selector(VideoScreen::handleVideoDisplayed), this);
    PokktNativeManager::setListener(PokktNativeManager::VideoSkippedEvent, pokkt_event_selector(VideoScreen::handleVideoSkipped), this);
    PokktNativeManager::setListener(PokktNativeManager::VideoCompletedEvent, pokkt_event_selector(VideoScreen::handleVideoCompleted), this);
    PokktNativeManager::setListener(PokktNativeManager::VideoGratifiedEvent, pokkt_event_selector(VideoScreen::handleVideoGratified), this);
    
    PokktNativeManager::setListener(PokktNativeManager::DownloadCompletedEvent, pokkt_event_selector(VideoScreen::handleDownloadCompleted), this);
    PokktNativeManager::setListener(PokktNativeManager::DownloadFailedEvent, pokkt_event_selector(VideoScreen::handleDownloadFailed), this);
}

VideoScreen::~VideoScreen()
{
    PokktNativeManager::removeListener(PokktNativeManager::VideoClosedEvent);
    PokktNativeManager::removeListener(PokktNativeManager::VideoDisplayedEvent);
    PokktNativeManager::removeListener(PokktNativeManager::VideoSkippedEvent);
    PokktNativeManager::removeListener(PokktNativeManager::VideoCompletedEvent);
    PokktNativeManager::removeListener(PokktNativeManager::VideoGratifiedEvent);
    
    PokktNativeManager::removeListener(PokktNativeManager::DownloadCompletedEvent);
    PokktNativeManager::removeListener(PokktNativeManager::DownloadFailedEvent);
}

void VideoScreen::handleVideoClosed(std::string message)
{
    if(s3eDeviceGetInt(S3E_DEVICE_OS) == S3E_OS_ID_IPHONE)
       s3eSurfaceSetInt( S3E_SURFACE_DEVICE_ORIENTATION_LOCK, S3E_SURFACE_PORTRAIT_FIXED );
    
    POKKTLOG("[POKKT-CPP][VideoScreen] %s", message.c_str());
    msgLbl->SetText(message.c_str());
}

void VideoScreen::handleVideoDisplayed(std::string message)
{
    POKKTLOG("[POKKT-CPP][VideoScreen] %s", message.c_str());
    msgLbl->SetText(message.c_str());
}

void VideoScreen::handleVideoSkipped(std::string message)
{
    POKKTLOG("[POKKT-CPP][VideoScreen] %s", message.c_str());
    msgLbl->SetText(message.c_str());
}

void VideoScreen::handleVideoCompleted(std::string message)
{
    POKKTLOG("[POKKT-CPP][VideoScreen] %s", message.c_str());
    msgLbl->SetText(message.c_str());
}

void VideoScreen::handleVideoGratified(std::string coins)
{
    POKKTLOG("[POKKT-CPP][VideoScreen] Coins earned from video: %s", coins.c_str());
    float coinsFloat = 0;
    std::stringstream(coins) >> coinsFloat;
    _coinsEarned += coinsFloat;
    char buf[100] = "";
    sprintf(buf, "%f", _coinsEarned);
    pointsEarnedLbl->SetText(buf);
}

void VideoScreen::handleDownloadCompleted(std::string coinsToEarn)
{
    double vc = PokktNativeManager::getVideoVc();
    
    // enable buttons
    POKKTLOG("[POKKT-CPP][VideoScreen] enabling buttons! Video vc is: %f", vc);
    
    msgLbl->SetText("Video downloaded!");
    
    playIncentBtn->m_IsVisible = true;
    playNonIncentBtn->m_IsVisible = true;
    playIncentLbl->m_IsVisible = true;
    playNonIncentLbl->m_IsVisible = true;
}

void VideoScreen::handleDownloadFailed(std::string message)
{
    POKKTLOG("[POKKT-CPP][VideoScreen] Failed to download video!");
    msgLbl->SetText("Failed to download video!");
    playIncentBtn->m_IsVisible = false;
    playNonIncentBtn->m_IsVisible = false;
    playIncentLbl->m_IsVisible = false;
    playNonIncentLbl->m_IsVisible = false;
}

void VideoScreen::Update(float deltaTime, float alphaMul)
{
    if(!m_IsActive)
        return;
    
    Scene:Scene::Update(deltaTime, alphaMul);
    
    //Detect screen tap
    if(m_IsInputActive && m_Manager->GetCurrent() == this && !g_pInput->m_Touched && g_pInput->m_PrevTouched)
    {
        g_pInput->Reset();
        
        if(startCachingBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            PokktNativeManager::cacheVideoCampaign();
        }
        else if(playIncentBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            if(PokktNativeManager::isVideoAvailable())
            {
                if(s3eDeviceGetInt(S3E_DEVICE_OS) == S3E_OS_ID_IPHONE)
                    s3eSurfaceSetInt( S3E_SURFACE_DEVICE_ORIENTATION_LOCK, S3E_SURFACE_LANDSCAPE_FIXED );
                pokktConfig->setScreenName("samplescreen");
                PokktNativeManager::getVideo(pokktConfig);
            }
        }
        else if(playNonIncentBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            if(PokktNativeManager::isVideoAvailable())
            {
                if(s3eDeviceGetInt(S3E_DEVICE_OS) == S3E_OS_ID_IPHONE)
                    s3eSurfaceSetInt( S3E_SURFACE_DEVICE_ORIENTATION_LOCK, S3E_SURFACE_LANDSCAPE_FIXED );
                pokktConfig->setScreenName("samplescreen");
                PokktNativeManager::getVideoNonIncent(pokktConfig);
            }
        }
    }
}

void VideoScreen::Render()
{
    Scene::Render();
}

void VideoScreen::Init()
{
    Scene::Init();
    
    // Create UI
    CSprite* background = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2, (float)IwGxGetScreenHeight() / 2, g_pResources->getScreenBG(), 0.5f, 0.5f);
    // Fit background to screen size
    background->m_ScaleX = (float)IwGxGetScreenWidth() / background->GetImage()->GetWidth();
    background->m_ScaleY = (float)IwGxGetScreenHeight() / background->GetImage()->GetHeight();
    AddChild(background);
    
    CSprite* logo = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2, (float)IwGxGetScreenHeight() * 0.25f, g_pResources->getLogo(), 0.5f, 0.5f);
    AddChild(logo);
    
    //button 1
    float y_pos = (float)IwGxGetScreenHeight() * 0.56f;
    startCachingBtn = UIComponents::getSprite(IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getBlueButton(), 0.5f, 0.5f);
    AddChild(startCachingBtn);
    
    y_pos = (float)IwGxGetScreenHeight() * 0.57f;
    startCachingLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Start Caching");
    AddChild(startCachingLbl);
    
    //button 2
    y_pos = (float)IwGxGetScreenHeight() * 0.64f;
    playIncentBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getBlueButton(), 0.5f, 0.5f);
    AddChild(playIncentBtn);
    playIncentBtn->m_IsVisible = false;
    
    y_pos = (float)IwGxGetScreenHeight() * 0.65f;
    playIncentLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Play Incent Video To Earn");
    AddChild(playIncentLbl);
    playIncentLbl->m_IsVisible = false;
    
    //button3
    y_pos = (float)IwGxGetScreenHeight() * 0.72f;
    playNonIncentBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getBlueButton(), 0.5f, 0.5f);
    AddChild(playNonIncentBtn);
    playNonIncentBtn->m_IsVisible = false;
    
    y_pos = (float)IwGxGetScreenHeight() * 0.73f;
    playNonIncentLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Play Non-Incent Video");
    AddChild(playNonIncentLbl);
    playNonIncentLbl->m_IsVisible = false;
    
    pointsEarnedLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, (float)IwGxGetScreenHeight() * 0.45f, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Points earned: 0");
    AddChild(pointsEarnedLbl);
    
    msgLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, (float)IwGxGetScreenHeight() * 0.5f, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Button will get enable after caching video.");
    AddChild(msgLbl);
}

void VideoScreen::initPokkt()
{
    if(Storage::getAutoCaching())
    {
        startCachingBtn->m_IsVisible = false;
        startCachingLbl->m_IsVisible = false;
    }
    else
    {
        startCachingBtn->m_IsVisible = true;
        startCachingLbl->m_IsVisible = true;
    }
    
    // SET THESE UP AS PER VALUES PROVIDED TO YOU
    
    pokktConfig->setSecurityKey("iJ02lJss0M");
    pokktConfig->setApplicationId("a2717a45b835b5e9f50284a38d62a74e");
    pokktConfig->setIntegrationType(PokktMarmaladeConfig::INTEGRATION_TYPE_ALL);
    
    // set auto caching
    pokktConfig->setAutoCacheVideo(Storage::getAutoCaching());
    
    // set params to init pokkt
    PokktNativeManager::initPokkt(pokktConfig);
    PokktNativeManager::startSession(pokktConfig);
    // pokkt init for video ads
    pokktConfig->setThirdPartyUserId("123456");
    pokktConfig->setSkipEnabled(true);
    POKKTLOG("[POKKT-CPP][VideoScreen] Pokkt SDK Version: %s", PokktNativeManager::getPokktSDKVersion().c_str());
    pokktConfig->setMobileNo("9900064040");
    pokktConfig->setAge("32");
    pokktConfig->setBackButtonDisabled(true);
    pokktConfig->setBirthday("20/08/1983");
    //pokktConfig->setCloseOnSuccessFlag(true);
    pokktConfig->setCustomSkipMessage("Are you sure?");
    pokktConfig->setDefaultSkipTime(5);
    pokktConfig->setEducation("MCA");
    pokktConfig->setEmailAddress("pankaj454k@gmail.com");
    pokktConfig->setEmployment("Engineer");
    pokktConfig->setFacebookId("pankaj454k");
    pokktConfig->setIncentivised(true);
    pokktConfig->setLocation("Bangalore");
    pokktConfig->setMaritalStatus("Married");
    pokktConfig->setMaturityRating("for all");
    pokktConfig->setName("Pankaj");
    pokktConfig->setNationality("Indian");
    pokktConfig->setSex("Male");
    pokktConfig->setTwitterHandle("pankaj454k");
    
    //pokktConfig->setSelectedAnalyticsType(GOOGLE_ANALYTICS);
    //pokktConfig->setGoogleAnalyticsID("12345");
    
    PokktNativeManager::sendAppInfo();
    
}


